Struct streamdata::AvailableIter
source · pub struct AvailableIter<'state, Decoder, Buffer>where
Decoder: Decoder<Buffer>,
Buffer: Buffer,{ /* private fields */ }Expand description
Iterate over the data readily available in the state, decoding the values on the fly.
When the error is returned, the further progress is no longer possible
because the iterator will (most certainly, but actually depending on
the Decoder implementation) be stuck, trying to decode the same data over
and over again. The way to continue from this situation is to give up on
the iterator, and either give up on the whole State
(by [Self::finish]-ing it) or try to correct the state by altering
the buffer somehow.
This can be ergonomic when used with .collect::<Result<Vec<_>, _>.
Implementations
sourceimpl<'state, Decoder, Buffer> AvailableIter<'state, Decoder, Buffer>where
Decoder: Decoder<Buffer>,
Buffer: Buffer,
impl<'state, Decoder, Buffer> AvailableIter<'state, Decoder, Buffer>where Decoder: Decoder<Buffer>, Buffer: Buffer,
sourcepub fn buffer(&self) -> &Buffer
pub fn buffer(&self) -> &Buffer
View access to the state buffer.
This can be useful for inspecting the buffer after the chunks have beed added to it.
sourcepub fn try_drain(self) -> Result<(), <Decoder as Decoder<Buffer>>::Error>
pub fn try_drain(self) -> Result<(), <Decoder as Decoder<Buffer>>::Error>
Decode and drop all available data, or fail with the first encountered decoding error.
sourcepub fn try_collect<T>(self) -> Result<T, <Decoder as Decoder<Buffer>>::Error>where
T: FromIterator<<Decoder as Decoder<Buffer>>::Value>,
pub fn try_collect<T>(self) -> Result<T, <Decoder as Decoder<Buffer>>::Error>where T: FromIterator<<Decoder as Decoder<Buffer>>::Value>,
Decode and collect all available data, or fail with the first encountered decoding error.