pub trait Buffer {
// Required methods
fn append(&mut self, chunk: &[u8]);
fn view(&self) -> &[u8] ⓘ;
fn advance(&mut self, bytes: usize);
}Expand description
Buffer captures the interface we require from the piece that maintains
the crate::State buffer.
This buffer is intended for keeping the undecoded partial chunks.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".